==> fap-0.9.0pre1.tar.bz2: fap-0.9.0pre1/src/audio/input/madBackend.h <==
/*
 *  Copyright (C) 2006-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef MP3_H
#define MP3_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifdef HAVE_MAD_H
#include <mad.h>

#include "inputBackend.h"
#include "AutoDLL.h"

#include <fx.h>

#if defined(HAVE_MMAP) || defined(_WIN32)
#  include <FXMemMap.h>
#else
#  error
#endif

/*****************************************************************/

typedef struct {
	FXbool		fastscan;
} madConfig_t;

/*****************************************************************/

#include "configFrame.h"

class madConfig : public configFrame {
	FXDECLARE(madConfig)

private:
	FXDataTarget	_scan;

private:
	madConfig() {};
	madConfig(const madConfig&);
	madConfig& operator=(const madConfig&);

public:
	madConfig(FXPacker* win);
	virtual ~madConfig() {};
};

/*****************************************************************/

class madBackend : public inputBackend {

	friend class madConfig;

private:
	static madConfig_t	_settings;

private:
	mad_stream	_stream;
	mad_frame	_frame;
	mad_synth	_synth;
	FXuint		_idx;


	FXuint		_samplerate;
	FXuint		_channels;
	FXuint		_scalebits;

	FXuchar		*_data;
	FXuint		_length;

#if defined(HAVE_MMAP) || defined(_WIN32)
	FXMemMap	_memMap;
#else
	FXFile		_file;
#endif

	static const AutoDLL	_dll;

public:
	static const char* dl_mad_version;
	static const char* dl_mad_copyright;

private:
	static void (*dl_mad_stream_init)(struct mad_stream*);
	static void (*dl_mad_stream_finish)(struct mad_stream*);
	static void (*dl_mad_stream_buffer)(struct mad_stream*, unsigned char const *, unsigned long);
	static int (*dl_mad_stream_sync)(struct mad_stream*);

	static void (*dl_mad_header_init)(struct mad_header*);
	static int (*dl_mad_header_decode)(struct mad_header*, struct mad_stream*);

	static void (*dl_mad_frame_init)(struct mad_frame*);
	static void (*dl_mad_frame_finish)(struct mad_frame*);
	static int (*dl_mad_frame_decode)(struct mad_frame*, struct mad_stream*);
	static void (*dl_mad_frame_mute)(struct mad_frame*);

	static void (*dl_mad_synth_init)(struct mad_synth*);
	static void (*dl_mad_synth_mute)(struct mad_synth*);
	static void (*dl_mad_synth_frame)(struct mad_synth*, struct mad_frame const*);

private:
	int getXing(const char* buf);

public:
	madBackend();
	~madBackend();

	static const char name[];

	static bool init();

	/// Factory method
	static input* factory() { return new madBackend(); }

	/// Check if we support ext
	static bool supports(const char* fileName);

	/// Get supported extension
	FXString ext() const;

	/// Open file
	bool open(const FXString& fileName);

	/// Close file
	void close();

	/// Rewind to start
	const bool rewind();

	/// Get samplerate
	const unsigned int samplerate() const { return _samplerate; }

	/// Get channels
	const unsigned int channels() const { return _channels; }

	/// Get precision
	const sample_t precision() const { return SAMPLE_FIXED; }

	/// Get fractional scale for fixed point types
	const unsigned int fract() const { return MAD_F_FRACBITS; }

	/// Callback function
	size_t fillBuffer(void* buffer, const size_t bufferSize, const unsigned int seconds);

	/// Open config dialog
	void config(FXPacker* win) { new madConfig(win); }

	void loadSettings();

	void saveSettings();
};

#endif

#endif

==> fap-0.9.2.tar.bz2: fap-0.9.2/src/audio/input/madBackend.h <==
/*
 *  Copyright (C) 2006-2011 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef MP3_H
#define MP3_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifdef HAVE_MAD_H
#include <mad.h>

#include "inputBackend.h"
#include "AutoDLL.h"

#include <fx.h>

#if defined(HAVE_MMAP) || defined(_WIN32)
#  include <FXMemMap.h>
#else
#  error
#endif

/*****************************************************************/

typedef struct {
	FXbool		fastscan;
} madConfig_t;

/*****************************************************************/

#include "configFrame.h"

class madConfig : public configFrame {
	FXDECLARE(madConfig)

private:
	FXDataTarget	_scan;

private:
	madConfig() {};
	madConfig(const madConfig&);
	madConfig& operator=(const madConfig&);

public:
	madConfig(FXPacker* win);
	virtual ~madConfig() {};
};

/*****************************************************************/

class madBackend : public inputBackend {

	friend class madConfig;

private:
	static madConfig_t	_settings;

private:
	mad_stream	_stream;
	mad_frame	_frame;
	mad_synth	_synth;
	FXuint		_idx;


	FXuint		_samplerate;
	FXuint		_channels;
	FXuint		_scalebits;

	FXuchar		*_data;
	FXuint		_length;

#if defined(HAVE_MMAP) || defined(_WIN32)
	FXMemMap	_memMap;
#else
	FXFile		_file;
#endif

	static const AutoDLL	_dll;

public:
	static const char* dl_mad_version;
	static const char* dl_mad_copyright;

private:
	static void (*dl_mad_stream_init)(struct mad_stream*);
	static void (*dl_mad_stream_finish)(struct mad_stream*);
	static void (*dl_mad_stream_buffer)(struct mad_stream*, unsigned char const *, unsigned long);
	static int (*dl_mad_stream_sync)(struct mad_stream*);

	static void (*dl_mad_header_init)(struct mad_header*);
	static int (*dl_mad_header_decode)(struct mad_header*, struct mad_stream*);

	static void (*dl_mad_frame_init)(struct mad_frame*);
	static void (*dl_mad_frame_finish)(struct mad_frame*);
	static int (*dl_mad_frame_decode)(struct mad_frame*, struct mad_stream*);
	static void (*dl_mad_frame_mute)(struct mad_frame*);

	static void (*dl_mad_synth_init)(struct mad_synth*);
	static void (*dl_mad_synth_mute)(struct mad_synth*);
	static void (*dl_mad_synth_frame)(struct mad_synth*, struct mad_frame const*);

private:
	madBackend();

	int getXing(const char* buf);

public:
	~madBackend();

	static const char name[];

	static bool init();

	/// Factory method
	static input* factory() { return new madBackend(); }

	/// Check if we support ext
	static bool supports(const char* fileName);

	/// Get supported extension
	FXString ext() const;

	/// Open file
	bool open(const FXString& fileName);

	/// Close file
	void close();

	/// Rewind to start
	bool rewind();

	/// Get samplerate
	unsigned int samplerate() const { return _samplerate; }

	/// Get channels
	unsigned int channels() const { return _channels; }

	/// Get precision
	sample_t precision() const { return SAMPLE_FIXED; }

	/// Get fractional scale for fixed point types
	unsigned int fract() const { return MAD_F_FRACBITS; }

	/// Callback function
	size_t fillBuffer(void* buffer, const size_t bufferSize, const unsigned int seconds);

	/// Open config dialog
	void config(FXPacker* win) { new madConfig(win); }

	void loadSettings();

	void saveSettings();
};

#endif

#endif
